@echo off
rem *******************************************************************************
rem  Eléments sous licence - Propriétés d'IBM
rem  (c) Copyright IBM Corporation 2012. All Rights Reserved.
rem
rem  Note to U.S. Government Users Restricted Rights:
rem  Use, duplication or disclosure restricted by GSA ADP Schedule
rem  Contract with IBM Corp.
rem  *******************************************************************************


REM #############################################################
REM #
REM # Définissez les variables d'environnement correspondant aux
REM # paramètres de script dm_upgrade.bat et leurs valeurs par défaut
REM #
REM #===========================================================
REM #
REM # Ce fichier est lu au début de l'exécution du script
REM # dm_upgrade.bat. Il associe une variable d'environnement
REM # par paramètre valide à une valeur par défaut prédéfinie.
REM #
REM # Les utilisateurs peuvent être amenés à modifier la valeur par
REM # défaut afin de lancer le script dm_upgrade.bat avec leurs
REM # propres valeurs sans avoir à entrer manuellement le paramètre
REM # et sa valeur correspondante sur la ligne de commande.
REM #
REM # AVERTISSEMENT :
REM # Les variables ne doivent pas toutes être définies pour chaque
REM # application.  Lisez avec attention chaque commentaire avant de
REM # modifier la valeur.
REM #
REM #############################################################

rem Paramètre : -oldApplicationHome
rem Syntaxe : -oldApplicationHome <chemin rép>
rem Description :
rem 	Chemin d'accès complet au répertoire principal de l'application dans l'ancienne installation.
rem Valeur par défaut :
rem 	<none>
rem Contraintes :
rem  - il s'agit d'un paramètre obligatoire
rem  - <chemin rép> doit correspondre à un répertoire existant se terminant par 'server\conf'
rem    exemple : D:\Jazz\IBM\JazzInstallDir\jazz\server\conf
rem
set OLD_APPLICATION_HOME=

rem Paramètre : -applicationContextRoot
rem Syntaxe : -applicationContextRoot <racine>
rem Description :
rem 	Racine de contexte d'application.
rem Valeur par défaut :
rem 	dm
rem Contraintes :
rem  - <racine> doit correspondre à un nom unique de répertoire valide (sans barre oblique au début)
rem
set APPLICATION_CONTEXT_ROOT=dm

rem Paramètre : -oldApplicationVersion
rem Syntaxe : -oldApplicationVersion <version>
rem Description :
rem 	La version de DM en cours de mise à niveau. Par défaut, elle est
rem  déterminée en appliquant la commande repotools -version à l'ancienne application.
rem Valeur par défaut :
rem 	<none>
rem Contraintes :
rem  - doit correspondre à une chaîne de version complète
rem    exemple : 4.0
rem
set OLD_APPLICATION_VERSION=

rem Paramètre : -newApplicationHome
rem Syntaxe : -newApplicationHome <chemin rép>
rem Description :
rem 	Chemin d'accès au répertoire principal de l'application dans la nouvelle installation.
rem Valeur par défaut :
rem 	<rép actuel>/conf
rem Contraintes :
rem  - Il s'agit d'un paramètre obligatoire
rem  - <chemin rép> doit correspondre à un répertoire existant se terminant par 'server\conf'
rem    exemple : D:\Jazz\IBM\JazzInstallDir\server\conf
rem
set NEW_APPLICATION_HOME="%START_DIR%\conf"

rem Paramètre : -updateTomcatFiles
rem Syntaxe : -updateTomcatFiles <yes | no>
rem Description :
rem 	Indique si les fichiers de configuration Tomcat doivent être mis à jour.
rem Valeur par défaut :
rem 	yes
rem Contraintes :
rem  - Seules les valeurs 'yes' et 'no' sont admises
rem
set UPDATE_TOMCAT_FILES=yes

rem Paramètre : -oldApplicationTomcatHome
rem Syntaxe : -oldApplicationTomcatHome <chemin rép>
rem Description :
rem 	Chemin d'accès complet au répertoire principal Tomcat dans l'ancienne installation.
rem Valeur par défaut :
rem 	<none>
rem Contraintes :
rem  - Doit correspondre à un répertoire existant
rem
set OLD_APP_TOMCAT_HOME=

rem Paramètre : -newApplicationTomcatHome
rem Syntaxe : -newApplicationTomcatHome <chemin rép>
rem Description :
rem 	Chemin d'accès au répertoire racine Tomcat de l'application dans la nouvelle installation.
rem Valeur par défaut :
rem 	<none>
rem
set NEW_APP_TOMCAT_HOME=

rem Paramètre : -newJTSHome
rem Syntaxe : -newJTSHome <chemin rép>
rem Description :
rem 	Chemin d'accès au répertoire de configuration du serveur JTS que la nouvelle installation va utiliser.
rem Valeur par défaut :
rem 	Répertoire principal de la nouvelle application
rem Contraintes :
rem  - <chemin répertoire> doit correspondre à un répertoire existant se terminant par 'server\conf'
rem
set NEW_JTS_HOME=

rem Paramètre : -jtsContextRoot
rem Syntaxe : -jtsContextRoot <racine>
rem Description :
rem 	Racine de contexte du serveur JTS.
rem Valeur par défaut :
rem 	jts
rem Contraintes :
rem  - <racine> doit correspondre à un nom unique de répertoire valide (sans barre oblique au début)
rem
set JTS_CONTEXT_ROOT=jts

rem Paramètre : -noPrompt
rem Syntaxe : -noPrompt
rem Description :
rem 	Ne pas demander confirmation avant la création ou la modification des tables
rem Valeur par défaut :
rem 	<aucune>
rem Contraintes :
rem  - Les seules valeurs valides sont la valeur vide et 'noPrompt'
rem
rem set NO_PROMPT=noPrompt
set NO_PROMPT=

rem Paramètre : -noVerify
rem Syntaxe : -noVerify
rem Description :
rem 	Ne pas vérifier les fichiers teamserver.properties.
rem Valeur par défaut :
rem 	<aucune>
rem Contraintes :
rem  - Les seules valeurs valides sont la valeur vide et 'noVerify'
rem
rem set NO_VERIFY=noVerify
set NO_VERIFY=

rem Paramètre : -overwrite
rem Syntaxe : -overwrite
rem Description :
rem 	Indique si les fichiers existants doivent être remplacés.
rem Valeur par défaut :
rem 	no
rem Contraintes :
rem  - Les seules valeurs valides sont la valeur vide et 'overwrite=yes'
rem
rem set OVERWRITE=overwrite=yes
set OVERWRITE=

rem Paramètre : -noStepPrompt
rem Syntaxe : -noStepPrompt
rem Description :
rem 	Ne pas demander confirmation avant l'exécution d'une étape.
rem Valeur par défaut :
rem 	false
rem Contraintes :
rem  - Les seules valeurs valides sont 'true' ou 'false'
rem
rem set NO_STEP_PROMPT=true
set NO_STEP_PROMPT=false
